# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!! 
# This file is built by ./mktables from e.g. UnicodeData.txt.
# Any changes made here will be lost!

#
# This file supports:
# 	\p{CanadianAboriginal} (and fuzzy permutations)
# 
# Meaning: Script 'Canadian_Aboriginal'
#
return <<'END';
1401	1676	Canadian_Aboriginal
END
